@@ -1,12 +1,9 @@
-from __future__ import absolute_import, unicode_literals
-
 import datetime
 import json
 from threading import local
 from time import time
 
-from django.utils import six
-from django.utils.encoding import DjangoUnicodeDecodeError, force_text
+from django.utils.encoding import force_str
 
 from debug_toolbar import settings as dt_settings
 from debug_toolbar.utils import get_stack, get_template_info, tidy_stacktrace
@@ -39,6 +36,7 @@ recording = state.recording  # export function
 def wrap_cursor(connection, panel):
     if not hasattr(connection, "_djdt_cursor"):
         connection._djdt_cursor = connection.cursor
+        connection._djdt_chunked_cursor = connection.chunked_cursor
 
         def cursor(*args, **kwargs):
             # Per the DB API cursor() does not accept any arguments. There's
@@ -51,7 +49,13 @@ def wrap_cursor(connection, panel):
                 connection._djdt_cursor(*args, **kwargs), connection, panel
             )
 
+        def chunked_cursor(*args, **kwargs):
+            return state.Wrapper(
+                connection._djdt_chunked_cursor(*args, **kwargs), connection, panel
+            )
+
         connection.cursor = cursor
+        connection.chunked_cursor = chunked_cursor
         return cursor
 
 
@@ -59,9 +63,10 @@ def unwrap_cursor(connection):
     if hasattr(connection, "_djdt_cursor"):
         del connection._djdt_cursor
         del connection.cursor
+        del connection.chunked_cursor
 
 
-class ExceptionCursorWrapper(object):
+class ExceptionCursorWrapper:
     """
     Wraps a cursor and raises an exception on any operation.
     Used in Templates panel.
@@ -74,7 +79,7 @@ class ExceptionCursorWrapper(object):
         raise SQLQueryTriggered()
 
 
-class NormalCursorWrapper(object):
+class NormalCursorWrapper:
     """
     Wraps a cursor and logs queries.
     """
@@ -87,11 +92,8 @@ class NormalCursorWrapper(object):
         self.logger = logger
 
     def _quote_expr(self, element):
-        if isinstance(element, six.string_types):
-            try:
-                return "'%s'" % force_text(element).replace("'", "''")
-            except DjangoUnicodeDecodeError:
-                return repr(element)
+        if isinstance(element, str):
+            return "'%s'" % element.replace("'", "''")
         else:
             return repr(element)
 
@@ -104,17 +106,17 @@ class NormalCursorWrapper(object):
 
     def _decode(self, param):
         # If a sequence type, decode each element separately
-        if isinstance(param, list) or isinstance(param, tuple):
+        if isinstance(param, (tuple, list)):
             return [self._decode(element) for element in param]
 
         # If a dictionary type, decode each value separately
         if isinstance(param, dict):
             return {key: self._decode(value) for key, value in param.items()}
 
-        # make sure datetime, date and time are converted to string by force_text
+        # make sure datetime, date and time are converted to string by force_str
         CONVERT_TYPES = (datetime.datetime, datetime.date, datetime.time)
         try:
-            return force_text(param, strings_only=not isinstance(param, CONVERT_TYPES))
+            return force_str(param, strings_only=not isinstance(param, CONVERT_TYPES))
         except UnicodeDecodeError:
             return "(encoded string)"
 
@@ -141,6 +143,10 @@ class NormalCursorWrapper(object):
             conn = self.db.connection
             vendor = getattr(conn, "vendor", "unknown")
 
+            # Sql might be an object (such as psycopg Composed).
+            # For logging purposes, make sure it's str.
+            sql = str(sql)
+
             params = {
                 "vendor": vendor,
                 "alias": alias,
