@@ -1,5 +1,3 @@
-from __future__ import absolute_import, unicode_literals
-
 from collections import OrderedDict
 from contextlib import contextmanager
 from os.path import normpath
@@ -12,9 +10,7 @@ from django.db.models.query import QuerySet, RawQuerySet
 from django.template import RequestContext, Template
 from django.test.signals import template_rendered
 from django.test.utils import instrumented_test_render
-from django.utils import six
-from django.utils.encoding import force_text
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from debug_toolbar.panels import Panel
 from debug_toolbar.panels.sql.tracking import SQLQueryTriggered, recording
@@ -46,7 +42,7 @@ def _request_context_bind_template(self, template):
     self.context_processors = OrderedDict()
     updates = {}
     for processor in processors:
-        name = "%s.%s" % (processor.__module__, processor.__name__)
+        name = "{}.{}".format(processor.__module__, processor.__name__)
         context = processor(self.request)
         self.context_processors[name] = context
         updates.update(context)
@@ -69,24 +65,17 @@ class TemplatesPanel(Panel):
     """
 
     def __init__(self, *args, **kwargs):
-        super(TemplatesPanel, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.templates = []
-        # Refs GitHub issue #910
-        # Hold a series of seen dictionaries within Contexts. A dictionary is
-        # considered seen if it is `in` this list, requiring that the __eq__
-        # for the dictionary matches. If *anything* in the dictionary is
-        # different it is counted as a new layer.
-        self.seen_layers = []
-        # Holds all dictionaries which have been prettified for output.
-        # This should align with the seen_layers such that an index here is
-        # the same as the index there.
+        # An associated list of dictionaries and their prettified
+        # representation.
         self.pformat_layers = []
 
     def _store_template_info(self, sender, **kwargs):
         template, context = kwargs["template"], kwargs["context"]
 
         # Skip templates that we are generating through the debug toolbar.
-        is_debug_toolbar_template = isinstance(template.name, six.string_types) and (
+        is_debug_toolbar_template = isinstance(template.name, str) and (
             template.name.startswith("debug_toolbar/")
             or template.name.startswith(
                 tuple(self.toolbar.config["SKIP_TEMPLATE_PREFIXES"])
@@ -98,15 +87,15 @@ class TemplatesPanel(Panel):
         context_list = []
         for context_layer in context.dicts:
             if hasattr(context_layer, "items") and context_layer:
-                # Refs GitHub issue #910
-                # If we can find this layer in our pseudo-cache then find the
-                # matching prettified version in the associated list.
+                # Check if the layer is in the cache.
                 key_values = sorted(context_layer.items())
-                if key_values in self.seen_layers:
-                    index = self.seen_layers.index(key_values)
-                    pformatted = self.pformat_layers[index]
-                    context_list.append(pformatted)
-                else:
+                pformatted = None
+                for _key_values, _pformatted in self.pformat_layers:
+                    if _key_values == key_values:
+                        pformatted = _pformatted
+                        break
+
+                if pformatted is None:
                     temp_layer = {}
                     for key, value in context_layer.items():
                         # Replace any request elements - they have a large
@@ -125,17 +114,13 @@ class TemplatesPanel(Panel):
                         # QuerySet would trigger the database: user can run the
                         # query from SQL Panel
                         elif isinstance(value, (QuerySet, RawQuerySet)):
-                            model_name = "%s.%s" % (
-                                value.model._meta.app_label,
-                                value.model.__name__,
-                            )
-                            temp_layer[key] = "<<%s of %s>>" % (
+                            temp_layer[key] = "<<{} of {}>>".format(
                                 value.__class__.__name__.lower(),
-                                model_name,
+                                value.model._meta.label,
                             )
                         else:
+                            recording(False)
                             try:
-                                recording(False)
                                 saferepr(value)  # this MAY trigger a db query
                             except SQLQueryTriggered:
                                 temp_layer[key] = "<<triggers database query>>"
@@ -147,20 +132,9 @@ class TemplatesPanel(Panel):
                                 temp_layer[key] = value
                             finally:
                                 recording(True)
-                    # Refs GitHub issue #910
-                    # If we've not seen the layer before then we will add it
-                    # so that if we see it again we can skip formatting it.
-                    self.seen_layers.append(key_values)
-                    # Note: this *ought* to be len(...) - 1 but let's be safe.
-                    index = self.seen_layers.index(key_values)
-                    try:
-                        pformatted = force_text(pformat(temp_layer))
-                    except UnicodeEncodeError:
-                        pass
-                    else:
-                        # Note: this *ought* to be len(...) - 1 but let's be safe.
-                        self.pformat_layers.insert(index, pformatted)
-                        context_list.append(pformatted)
+                    pformatted = pformat(temp_layer)
+                    self.pformat_layers.append((key_values, pformatted))
+                context_list.append(pformatted)
 
         kwargs["context"] = context_list
         kwargs["context_processors"] = getattr(context, "context_processors", None)
